# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AnalysisResultResponseMetadataPython(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'int',
        'implementation_name': 'str',
        'major': 'int',
        'micro': 'int',
        'minor': 'int',
        'releaselevel': 'str',
        'serial': 'int'
    }

    attribute_map = {
        'api_version': 'api_version',
        'implementation_name': 'implementation_name',
        'major': 'major',
        'micro': 'micro',
        'minor': 'minor',
        'releaselevel': 'releaselevel',
        'serial': 'serial'
    }

    def __init__(self, api_version=None, implementation_name=None, major=None, micro=None, minor=None, releaselevel=None, serial=None):  # noqa: E501
        """AnalysisResultResponseMetadataPython - a model defined in Swagger"""  # noqa: E501
        self._api_version = None
        self._implementation_name = None
        self._major = None
        self._micro = None
        self._minor = None
        self._releaselevel = None
        self._serial = None
        self.discriminator = None
        self.api_version = api_version
        self.implementation_name = implementation_name
        self.major = major
        self.micro = micro
        self.minor = minor
        self.releaselevel = releaselevel
        self.serial = serial

    @property
    def api_version(self):
        """Gets the api_version of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The api_version of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: int
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this AnalysisResultResponseMetadataPython.


        :param api_version: The api_version of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: int
        """
        if api_version is None:
            raise ValueError("Invalid value for `api_version`, must not be `None`")  # noqa: E501

        self._api_version = api_version

    @property
    def implementation_name(self):
        """Gets the implementation_name of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The implementation_name of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: str
        """
        return self._implementation_name

    @implementation_name.setter
    def implementation_name(self, implementation_name):
        """Sets the implementation_name of this AnalysisResultResponseMetadataPython.


        :param implementation_name: The implementation_name of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: str
        """
        if implementation_name is None:
            raise ValueError("Invalid value for `implementation_name`, must not be `None`")  # noqa: E501

        self._implementation_name = implementation_name

    @property
    def major(self):
        """Gets the major of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The major of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: int
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this AnalysisResultResponseMetadataPython.


        :param major: The major of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: int
        """
        if major is None:
            raise ValueError("Invalid value for `major`, must not be `None`")  # noqa: E501

        self._major = major

    @property
    def micro(self):
        """Gets the micro of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The micro of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: int
        """
        return self._micro

    @micro.setter
    def micro(self, micro):
        """Sets the micro of this AnalysisResultResponseMetadataPython.


        :param micro: The micro of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: int
        """
        if micro is None:
            raise ValueError("Invalid value for `micro`, must not be `None`")  # noqa: E501

        self._micro = micro

    @property
    def minor(self):
        """Gets the minor of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The minor of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: int
        """
        return self._minor

    @minor.setter
    def minor(self, minor):
        """Sets the minor of this AnalysisResultResponseMetadataPython.


        :param minor: The minor of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: int
        """
        if minor is None:
            raise ValueError("Invalid value for `minor`, must not be `None`")  # noqa: E501

        self._minor = minor

    @property
    def releaselevel(self):
        """Gets the releaselevel of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The releaselevel of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: str
        """
        return self._releaselevel

    @releaselevel.setter
    def releaselevel(self, releaselevel):
        """Sets the releaselevel of this AnalysisResultResponseMetadataPython.


        :param releaselevel: The releaselevel of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: str
        """
        if releaselevel is None:
            raise ValueError("Invalid value for `releaselevel`, must not be `None`")  # noqa: E501

        self._releaselevel = releaselevel

    @property
    def serial(self):
        """Gets the serial of this AnalysisResultResponseMetadataPython.  # noqa: E501


        :return: The serial of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :rtype: int
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this AnalysisResultResponseMetadataPython.


        :param serial: The serial of this AnalysisResultResponseMetadataPython.  # noqa: E501
        :type: int
        """
        if serial is None:
            raise ValueError("Invalid value for `serial`, must not be `None`")  # noqa: E501

        self._serial = serial

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalysisResultResponseMetadataPython, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalysisResultResponseMetadataPython):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class InlineResponse200(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'parameters': 'InlineResponse200Parameters',
        'hardware_environments': 'list[InlineResponse200HardwareEnvironments]'
    }

    attribute_map = {
        'parameters': 'parameters',
        'hardware_environments': 'hardware_environments'
    }

    def __init__(self, parameters=None, hardware_environments=None):  # noqa: E501
        """InlineResponse200 - a model defined in Swagger"""  # noqa: E501
        self._parameters = None
        self._hardware_environments = None
        self.discriminator = None
        self.parameters = parameters
        self.hardware_environments = hardware_environments

    @property
    def parameters(self):
        """Gets the parameters of this InlineResponse200.  # noqa: E501


        :return: The parameters of this InlineResponse200.  # noqa: E501
        :rtype: InlineResponse200Parameters
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this InlineResponse200.


        :param parameters: The parameters of this InlineResponse200.  # noqa: E501
        :type: InlineResponse200Parameters
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    @property
    def hardware_environments(self):
        """Gets the hardware_environments of this InlineResponse200.  # noqa: E501


        :return: The hardware_environments of this InlineResponse200.  # noqa: E501
        :rtype: list[InlineResponse200HardwareEnvironments]
        """
        return self._hardware_environments

    @hardware_environments.setter
    def hardware_environments(self, hardware_environments):
        """Sets the hardware_environments of this InlineResponse200.


        :param hardware_environments: The hardware_environments of this InlineResponse200.  # noqa: E501
        :type: list[InlineResponse200HardwareEnvironments]
        """
        if hardware_environments is None:
            raise ValueError("Invalid value for `hardware_environments`, must not be `None`")  # noqa: E501

        self._hardware_environments = hardware_environments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
# thamos
# Copyright(C) 2018 - 2021 Fridolin Pokorny
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Exception hierarchy in Thamos."""


class ThamosException(Exception):
    """A base class for exceptions in Thamos."""


class NoProjectDirError(ThamosException):
    """An exception raised if the project directory cannot be found."""


class InternalError(ThamosException):
    """An exception raised on internal programming errors."""


class NoApiSupported(ThamosException):
    """Raised if client and Thoth server does not support same API versions."""


class ServiceUnavailable(ThamosException):
    """Raised if Thoth service is not available."""


class UnknownAnalysisType(ThamosException):
    """Raised analysis type (adviser, package-extract, ...) cannot be determined from analysis identifier."""


class NoRuntimeEnvironmentError(ThamosException):
    """An exception raised if no runtime environment could be found in configuration file."""


class RuntimeEnvironmentExistsError(ThamosException):
    """An exception raised the given runtime environment already exists."""


class NoRequirementsFormatError(ThamosException):
    """An exception raised if no requirements format could be found in configuration file."""


class ConfigurationError(ThamosException):
    """An exception raised if there are issues with configuration file."""


class TimeoutError(ThamosException):
    """An exception raised if the API takes longer than timeout limit."""


class ApiError(ThamosException):
    """An exception raised if the API doesn't return expected status code."""


class NoRequirementsFile(ThamosException):
    """An exception raised when requirements file is not present."""


class NoDevRequirements(ThamosException):
    """An exception raised if no development requirements are found during the installation process."""



# coding: utf-8

# flake8: noqa

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from thamos.swagger_client.thoth.advise_api import AdviseApi
from thamos.swagger_client.thoth.build_analysis_api import BuildAnalysisApi
from thamos.swagger_client.thoth.buildlogs_api import BuildlogsApi
from thamos.swagger_client.thoth.container_images_api import ContainerImagesApi
from thamos.swagger_client.thoth.git_hub_api import GitHubApi
from thamos.swagger_client.thoth.hardware_api import HardwareApi
from thamos.swagger_client.thoth.image_analysis_api import ImageAnalysisApi
from thamos.swagger_client.thoth.kebechet_api import KebechetApi
from thamos.swagger_client.thoth.provenance_api import ProvenanceApi
from thamos.swagger_client.thoth.python_packages_api import PythonPackagesApi
from thamos.swagger_client.thoth.s2i_api import S2iApi
# import ApiClient
from thamos.swagger_client.api_client import ApiClient
from thamos.swagger_client.configuration import Configuration
# import models into sdk package
from thamos.swagger_client.models.advise_input import AdviseInput
from thamos.swagger_client.models.advise_input_library_usage import AdviseInputLibraryUsage
from thamos.swagger_client.models.analysis_listing_response import AnalysisListingResponse
from thamos.swagger_client.models.analysis_log_response import AnalysisLogResponse
from thamos.swagger_client.models.analysis_response import AnalysisResponse
from thamos.swagger_client.models.analysis_response_error import AnalysisResponseError
from thamos.swagger_client.models.analysis_result_response import AnalysisResultResponse
from thamos.swagger_client.models.analysis_result_response_metadata import AnalysisResultResponseMetadata
from thamos.swagger_client.models.analysis_result_response_metadata_distribution import AnalysisResultResponseMetadataDistribution
from thamos.swagger_client.models.analysis_result_response_metadata_distribution_version_parts import AnalysisResultResponseMetadataDistributionVersionParts
from thamos.swagger_client.models.analysis_result_response_metadata_python import AnalysisResultResponseMetadataPython
from thamos.swagger_client.models.analysis_status_response import AnalysisStatusResponse
from thamos.swagger_client.models.analysis_status_response_status import AnalysisStatusResponseStatus
from thamos.swagger_client.models.analysis_unauthorized_error import AnalysisUnauthorizedError
from thamos.swagger_client.models.analysis_with_authentication_response import AnalysisWithAuthenticationResponse
from thamos.swagger_client.models.build import Build
from thamos.swagger_client.models.build_analysis_response import BuildAnalysisResponse
from thamos.swagger_client.models.build_analysis_response_base_image_analysis import BuildAnalysisResponseBaseImageAnalysis
from thamos.swagger_client.models.build_analysis_response_error import BuildAnalysisResponseError
from thamos.swagger_client.models.build_analysis_response_error_base_image_analysis import BuildAnalysisResponseErrorBaseImageAnalysis
from thamos.swagger_client.models.build_build_log import BuildBuildLog
from thamos.swagger_client.models.container_images_response import ContainerImagesResponse
from thamos.swagger_client.models.container_images_response_container_images import ContainerImagesResponseContainerImages
from thamos.swagger_client.models.container_images_response_parameters import ContainerImagesResponseParameters
from thamos.swagger_client.models.image_metadata_response import ImageMetadataResponse
from thamos.swagger_client.models.inline_response200 import InlineResponse200
from thamos.swagger_client.models.inline_response200_hardware_environments import InlineResponse200HardwareEnvironments
from thamos.swagger_client.models.inline_response200_parameters import InlineResponse200Parameters
from thamos.swagger_client.models.justification import Justification
from thamos.swagger_client.models.kebechet_metadata import KebechetMetadata
from thamos.swagger_client.models.kebechet_webhook_input import KebechetWebhookInput
from thamos.swagger_client.models.log import Log
from thamos.swagger_client.models.provenance_input import ProvenanceInput
from thamos.swagger_client.models.python_package_dependencies import PythonPackageDependencies
from thamos.swagger_client.models.python_package_dependencies_dependencies import PythonPackageDependenciesDependencies
from thamos.swagger_client.models.python_package_dependencies_error import PythonPackageDependenciesError
from thamos.swagger_client.models.python_package_indexes import PythonPackageIndexes
from thamos.swagger_client.models.python_package_indexes_indexes import PythonPackageIndexesIndexes
from thamos.swagger_client.models.python_package_metadata_response import PythonPackageMetadataResponse
from thamos.swagger_client.models.python_package_metadata_response_error import PythonPackageMetadataResponseError
from thamos.swagger_client.models.python_package_metadata_response_metadata import PythonPackageMetadataResponseMetadata
from thamos.swagger_client.models.python_package_versions_response import PythonPackageVersionsResponse
from thamos.swagger_client.models.python_package_versions_response_error import PythonPackageVersionsResponseError
from thamos.swagger_client.models.python_package_versions_response_versions import PythonPackageVersionsResponseVersions
from thamos.swagger_client.models.python_platforms import PythonPlatforms
from thamos.swagger_client.models.python_stack import PythonStack
from thamos.swagger_client.models.qeb_hwt_thamos_advise_input import QebHwtThamosAdviseInput
from thamos.swagger_client.models.runtime_environment import RuntimeEnvironment
from thamos.swagger_client.models.s2_i_python_response import S2IPythonResponse
from thamos.swagger_client.models.s2_i_python_response_s2i import S2IPythonResponseS2i
from thamos.swagger_client.models.stack_info import StackInfo
from thamos.swagger_client.models.stack_info_inner import StackInfoInner
